@@ -153,6 +153,7 @@ lst.addItem("strange");
 lst.addItem("superquadrics");
 lst.addItem("swarm");
 lst.addItem("swirl");
+lst.addItem("tetris");
 lst.addItem("thornbird");
 lst.addItem("triangle");
 lst.addItem("tube");
@@ -162,6 +163,7 @@ lst.addItem("voters");
 lst.addItem("wator");
 lst.addItem("wire");
 lst.addItem("world");
+lst.addItem("xjack");
 lst.addItem("worm");
 lst.addItem("blank");
 lst.addItem("bomb");
