@@ -75,6 +75,8 @@ static const char sccsid[] = "@(#)bat.c	4.07 97/11/24 xlockmore";
 #endif /* STANDALONE */
 #include "iostuff.h"
 
+#ifdef MODE_bat
+
 ModeSpecOpt bat_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -574,3 +576,5 @@ refresh_bat(ModeInfo * mi)
 
 	MI_CLEARWINDOWCOLORMAP(mi, bp->backGC, bp->black);
 }
+
+#endif /* MODE_bat */
