@@ -65,6 +65,10 @@ ModStruct   bug_description =
 
 #endif
 
+#if DEBUG
+#include <assert.h>
+#endif
+
 extern int  neighbors;
 
 #define BUGBITS(n,w,h)\
@@ -830,9 +834,15 @@ draw_bug(ModeInfo * mi)
 		hrow = bp->currbug->info.row;
 		colrow = hcol + hrow * bp->nhcols;
 		if (bp->currbug->info.energy-- < 0) {	/* Time to die, Bug */
+#if DEBUG
+			assert(bp->currbug == bp->arr[colrow]);
+#endif
 			/* back up one or else in void */
 			bp->currbug = bp->currbug->previous;
 			removefrom_buglist(bp, bp->arr[colrow]);
+#if DEBUG
+			assert(bp->arr[colrow] == 0);
+#endif
 			bp->arr[colrow] = 0;
 			eraseabug(mi, hcol, hrow);
 			bp->n--;
@@ -846,7 +856,8 @@ draw_bug(ModeInfo * mi)
 				absdir = (bp->currbug->info.direction +
 					  dirbug(&bp->currbug->info, bp->neighbors)) % bp->neighbors;
 			} while (!hexcmove(bp, hcol, hrow, absdir * ANGLES / bp->neighbors,
-			  &nhcol, &nhrow) || has_neighbor(bp, nhcol, nhrow));
+			  &nhcol, &nhrow) || has_neighbor(bp, nhcol, nhrow) ||
+			  bp->arr[nhcol + nhrow * bp->nhcols]);
 			bp->currbug->info.age++;
 			bp->currbug->info.energy--;
 			if (tryit <= ENOUGH) {
@@ -860,6 +871,9 @@ draw_bug(ModeInfo * mi)
 				bp->currbug->info.col = nhcol;
 				bp->currbug->info.row = nhrow;
 				bp->currbug->info.direction = absdir;
+#if DEBUG
+				assert(bp->arr[ncolrow] == 0);
+#endif
 				bp->arr[ncolrow] = bp->currbug;
 				if (bp->currbug->info.energy > STRONG &&
 				    bp->currbug->info.age > MATURE) {	/* breed */
