@@ -52,6 +52,8 @@ static const char sccsid[] = "@(#)coral.c 4.07 97/11/24 xlockmore";
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
+#ifdef MODE_coral
+
 ModeSpecOpt coral_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -104,7 +106,7 @@ rand_2(void)
 		i--;
 	} else {
 		i = 15;
-		r = LRAND();
+		r = (int) LRAND();
 	}
 
 	{
@@ -227,6 +229,8 @@ draw_coral(ModeInfo * mi)
 
 	int         i;
 
+	MI_IS_DRAWN(mi) = True;
+
 	for (i = 0; i < cp->nwalkers; i++) {
 		int         x = cp->walkers[i].x;
 		int         y = cp->walkers[i].y;
@@ -324,3 +328,5 @@ release_coral(ModeInfo * mi)
 		reefs = NULL;
 	}
 }
+
+#endif /* MODE_coral */
