@@ -36,7 +36,7 @@ static const char sccsid[] = "@(#)galaxy.c	4.07 97/11/24 xlockmore";
  * 30-Sep-94: Initial port by Hubert Feyer
  * 09-Mar-94: VMS can generate a random number 0.0 which results in a
  *            division by zero, corrected by Jouk Jansen
- *            <joukj@crys.chem.uva.nl>
+ *            <joukj@hrem.stm.tudelft.nl>
  */
 
 #ifdef STANDALONE
@@ -56,6 +56,8 @@ static const char sccsid[] = "@(#)galaxy.c	4.07 97/11/24 xlockmore";
 
 #endif /* STANDALONE */
 
+#ifdef MODE_galaxy
+
 static Bool tracks;
 
 #define DEF_TRACKS "False"
@@ -485,3 +487,5 @@ refresh_galaxy(ModeInfo * mi)
 {
 	MI_CLEARWINDOW(mi);
 }
+
+#endif /* MODE_galaxy */
