@@ -32,9 +32,7 @@ static const char sccsid[] = "@(#)rubik.c	4.07 97/11/24 xlockmore";
  * Since I'm not a native English speaker, my apologies for any grammatical
  * mistake.
  *
- * My e-mail addresses are
- * vianna@cat.cbpf.br 
- *         and
+ * My e-mail address is
  * m-vianna@usa.net
  *
  * Marcelo F. Vianna (Jul-31-1997)
@@ -139,7 +137,7 @@ static const char sccsid[] = "@(#)rubik.c	4.07 97/11/24 xlockmore";
 #include "vis.h"
 #endif /* !STANDALONE */
 
-#ifdef USE_GL
+#ifdef MODE_rubik
 
 #define DEF_HIDESHUFFLING     "False"
 
@@ -441,7 +439,7 @@ static float MaterialGray7[] =
 {0.7, 0.7, 0.7, 1.0};
 
 static rubikstruct *rubik = NULL;
-static GLuint objects;
+static GLuint objects = 0;
 
 #define ObjCubit        0
 
@@ -726,24 +724,22 @@ draw_cubit(ModeInfo * mi,
 }
 
 
-static      RubikSlice
-convertMove(rubikstruct * rp, RubikMove move)
+static void
+convertMove(rubikstruct * rp, RubikMove move, RubikSlice * slice)
 {
-	RubikSlice  slice;
 	RubikLoc    plane;
 
 	plane = rotateSlice[(int) move.face][move.direction % 2];
-	slice.face = plane.face;
-	slice.rotation = plane.rotation;
-	if (slice.rotation == CW)	/* I just know this to be true... */
-		slice.depth = AVSIZESQ - 1 - move.position;
+	(*slice).face = plane.face;
+	(*slice).rotation = plane.rotation;
+	if ((*slice).rotation == CW)	/* I just know this to be true... */
+		(*slice).depth = AVSIZESQ - 1 - move.position;
 	else
-		slice.depth = move.position;
-	slice.depth = slice.depth / AVSIZE;
-	/* If slice.depth = 0 then face 0, face 1, or face 2 moves */
+		(*slice).depth = move.position;
+	(*slice).depth = (*slice).depth / AVSIZE;
+	/* If (*slice).depth = 0 then face 0, face 1, or face 2 moves */
 	if (move.direction / 2)
-		slice.rotation = (plane.rotation == CW) ? CCW : CW;
-	return slice;
+		(*slice).rotation = (plane.rotation == CW) ? CCW : CW;
 }
 
 /* Assume for the moment that the size is at least 2 */
@@ -770,7 +766,7 @@ draw_cube(ModeInfo * mi)
 		slice.rotation = NO_ROTATION;
 		slice.depth = NO_DEPTH;
 	} else {
-		slice = convertMove(rp, rp->movement);
+		convertMove(rp, rp->movement, &slice);
 	}
 	rotatestep = (slice.rotation == CCW) ? rp->rotatestep : -rp->rotatestep;
 
@@ -1506,8 +1502,8 @@ compare_moves(rubikstruct * rp, RubikMove move1, RubikMove move2, Bool opp)
 {
 	RubikSlice  slice1, slice2;
 
-	slice1 = convertMove(rp, move1);
-	slice2 = convertMove(rp, move2);
+	convertMove(rp, move1, &slice1);
+	convertMove(rp, move2, &slice2);
 	if (slice1.face == slice2.face &&
 	    slice1.depth == slice2.depth) {
 		if (slice1.rotation == slice2.rotation) {	/* CW or CCW */
@@ -1683,8 +1679,8 @@ init_rubik(ModeInfo * mi)
 	}
 	rp = &rubik[screen];
 	rp->step = NRAND(90);
-	rp->PX = ((float) LRAND() / (float) RAND_MAX) * 2 - 1;
-	rp->PY = ((float) LRAND() / (float) RAND_MAX) * 2 - 1;
+	rp->PX = ((float) LRAND() / (float) MAXRAND) * 2.0 - 1.0;
+	rp->PY = ((float) LRAND() / (float) MAXRAND) * 2.0 - 1.0;
 
 	if ((rp->glx_context = init_GL(mi)) != NULL) {
 
@@ -1743,8 +1739,8 @@ draw_rubik(ModeInfo * mi)
 		bounced = 1;
 	}
 	if (bounced) {
-		rp->VX += ((float) LRAND() / (float) RAND_MAX) * 0.02 - 0.01;
-		rp->VX += ((float) LRAND() / (float) RAND_MAX) * 0.02 - 0.01;
+		rp->VX += ((float) LRAND() / (float) MAXRAND) * 0.02 - 0.01;
+		rp->VX += ((float) LRAND() / (float) MAXRAND) * 0.02 - 0.01;
 		if (rp->VX > 0.06)
 			rp->VX = 0.06;
 		if (rp->VY > 0.06)
