@@ -2,7 +2,7 @@
 /* text3d --- Shows moving 3D texts */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)text3d.cc	1.0 98/08/18 xlockmore";
+static const char sccsid[] = "@(#)text3d.cc	1.2 98/10/01 xlockmore";
 
 #endif
 
@@ -33,9 +33,9 @@ static const char sccsid[] = "@(#)text3d.cc	1.0 98/08/18 xlockmore";
  * REVISION HISTORY:
  *       08/23/98: add better handling of "faulty" fontfile and randomize 
  *                 fontfile if '-ttfont' value is a directory.
+ *		   Minor changes for AIX from Jouk Jansen (joukj@hrem.stm.tudelft.nl).
  * 
  * TODO : 
- *	 Cut the module in 2 parts: one for "pure C" and the other C++ ?
  *       I've still not really decided how to "move" the 3Dtext. 
  *       Function Animate needs still a lot of work! Help welcome !!
  *       
@@ -58,14 +58,24 @@ extern "C" {
 #include "xlockmore.h"		/* from the xscreensaver distribution */
 }
 #else /* !STANDALONE */
-extern "C" {
-#include "xlock.h"		/* from the xlockmore distribution */
-}
+# include "xlock.h"		/* from the xlockmore distribution */
+#include "vis.h"
 
 #endif /* !STANDALONE */
 
-#ifdef USE_GL
+#ifdef MODE_text3d
 
+#if 1
+#include <gltt/FTEngine.h>
+#include <gltt/FTFace.h>
+#include <gltt/FTInstance.h>
+#include <gltt/FTGlyph.h>
+#include <gltt/FTFont.h>
+#include <gltt/GLTTOutlineFont.h>
+#include <gltt/GLTTFont.h>
+#include <gltt/GLTTGlyphPolygonizer.h>
+#include <gltt/GLTTGlyphTriangulator.h>
+#else
 #include "FTEngine.h"
 #include "FTFace.h"
 #include "FTInstance.h"
@@ -75,6 +85,7 @@ extern "C" {
 #include "GLTTFont.h"
 #include "GLTTGlyphPolygonizer.h"
 #include "GLTTGlyphTriangulator.h"
+#endif
 
 #include "text3d.h"
 #include <GL/glu.h>
@@ -97,6 +108,8 @@ extern "C" {void release_text3d(ModeInfo * mi);}
 extern "C" {void refresh_text3d(ModeInfo * mi);}
 
 /* Manage Option vars */
+/* I found this font on NT in c:\WINDOWS\SYSTEM\ARIAL.TTF can also be found
+   on Windows95 in c:\windows\fonts\arial.ttf */
 #define DEF_FONT "arial.ttf"
 #define DEF_EXTRUSION  "25.0"
 #define DEF_ROTAMPL  "1.0"
@@ -144,18 +157,14 @@ ModStruct   text3d_description =
 
 static double camera_dist= 0.0; /* could it be a per screen variable ? */
 static double ref_camera_dist= 0.0; /* could it be a per screen variable ? */
-static text3dstruct *text3d = NULL;
+static text3dstruct *text3d = (text3dstruct*) NULL;
 
 /* Hacks to use $TOP/xlock/util.c and iostuff.c functions */
 extern "C" {char       *getWords(int screen, int screens);}
 extern "C" {FILE       *my_fopen(char *filename, char *type);}
 
 #if HAVE_DIRENT_H
-#define sel_font	sel_image
-/*
-#define font_list	image_list
-#define fonts_list	images_list
-*/
+#define sel_font	sel_image /* "rename" the sel_image function */
 
 extern "C" {void get_dir(char *fullpath, char *dir, char *filename);}
 extern "C" {int  sel_font(struct dirent *name);}
@@ -163,7 +172,7 @@ extern "C" {int  scan_dir(const char *directoryname,
 		     struct dirent ***namelist,
                      int (*select) (struct dirent *),
                      int (*compare) (const void *, const void *));}
-#endif
+#endif /* HAVE_DIRENT_H */
 
 /*
  *-----------------------------------------------------------------------------
@@ -189,8 +198,17 @@ readable(char *filename)
         (void) fclose(fp);
         return True;
 }
+#ifdef AIXV3
+extern "C" long int lrand48(void); /*Seems to missing in xlC for AIX3.2.5*/
+#endif
 
+	/*-------------------------------------------------------------*/
 #if HAVE_DIRENT_H
+
+#ifdef AIXV3
+extern "C" long int lrand48(void); /*Seems to missing in xlC for AIX3.2.5*/
+#endif
+
 static void
 randomFileFromList(char *directory,
                    struct dirent **filelist, int numfiles, char *file_local)
@@ -204,39 +222,34 @@ randomFileFromList(char *directory,
         }
 }
 
+	/*-------------------------------------------------------------*/
 static void
 getRandomFontFile(char *randomfile, char *randomfile_local)
 {
-	/* externs 'stolen' from $TOP/xlock/resource.c and util.c */
-        /*extern*/ char directory_r[DIRBUF];
+	/* mimic getRandomImageFile from $TOP/xlock/iostuff.c */
+        char directory_r[DIRBUF];
         struct dirent ***fonts_list;
-        /*extern*/ struct dirent **font_list = NULL;
-        /*extern*/ int  num_list;
+        struct dirent **font_list = (dirent**) NULL;
+        int  num_list;
+
+	/* extern char 'stolen' from $TOP/xlock/resource.c */				
         extern char filename_r[MAXNAMLEN];
 
         get_dir(randomfile, directory_r, filename_r);
-/*
-        if (font_list != NULL) {
-                int         i;
 
-                for (i = 0; i < num_list; i++) {
-                        (void) free((void *) font_list[i]);
-                        font_list[i] = NULL;
-                }
-                (void) free((void *) font_list);
-                font_list = NULL;
-        }
-*/
         fonts_list = (struct dirent ***) malloc(sizeof (struct dirent **));
 
-        num_list = scan_dir(directory_r, fonts_list, sel_font, NULL);
+        num_list = scan_dir(directory_r, fonts_list, sel_font, (int(*)(const
+						void*,const void*)) NULL);
         font_list = *fonts_list;
         (void) free((void *) fonts_list);
         if (num_list > 0) {
                 randomFileFromList(directory_r, font_list, num_list, randomfile_local);
         }
 }
-#endif
+#endif /* HAVE_DIRENT_H */
+
+	/*-------------------------------------------------------------*/
 
 #ifdef DIFFUSE_COLOR
 static void hsv_to_rgb( double h, double s, double v,
@@ -259,8 +272,9 @@ static void hsv_to_rgb( double h, double s, double v,
     case 5: *r=  v; *g= p1; *b= p2; break;
     }
 }
-#endif
+#endif /* DIFFUSE_COLOR */
 
+	/*-------------------------------------------------------------*/
 static void spheric_camera( text3dstruct * tp,
                             float center_x, float center_y, float center_z,
                             float phi, float theta, float radius )
@@ -283,6 +297,7 @@ static void spheric_camera( text3dstruct * tp,
   gluLookAt( x, y, z, center_x, center_y, center_z, vx, vy, vz );
 }
 
+	/*-------------------------------------------------------------*/
 class GLTTGlyphTriangles: public GLTTGlyphTriangulator
 {
 public:
@@ -307,7 +322,7 @@ public:
     }
   virtual ~GLTTGlyphTriangles()
     {
-    delete triangles;
+    delete [] triangles;
     triangles= 0;
     }
   void alloc()
@@ -350,6 +365,7 @@ Reshape(ModeInfo * mi, int width, int height)
         glMatrixMode(GL_MODELVIEW);
 }
 
+	/*-------------------------------------------------------------*/
 static void
 Animate(text3dstruct * tp)
 {
@@ -399,7 +415,7 @@ Animate(text3dstruct * tp)
       		tp->rfreq /= 1.15;
       		break;
 	}
-#else
+#else /* !FUNNY_ANIMATE */
   	const double angle_speed= 2.5/180.0*M_PI;
 
       	tp->phi-= angle_speed;
@@ -407,6 +423,7 @@ Animate(text3dstruct * tp)
 #endif
 }
 
+	/*-------------------------------------------------------------*/
 static void
 Draw(text3dstruct * tp,
 	Display    *display,
@@ -711,13 +728,13 @@ Draw(text3dstruct * tp,
       for( int j= 0; j < contour->nPoints; ++j )
         {
         FTGlyphVectorizer::POINT* point= contour->points + j;
-        delete point->data;
+        delete [] point->data;
         point->data= 0;
         }
       }
     }
 
-  delete tri;
+  delete [] tri;
   delete [] vec;
 }
 
@@ -771,11 +788,7 @@ init_text3d(ModeInfo * mi)
                 (void) fprintf(stderr,
                                "%s: could not read file \"%s\" !\n", MI_NAME(mi),fontfile);
 		(void) free((void *) text3d);
-		text3d = NULL;
-		/* 
-		 * Is it possible to use the "2D" text mode in the faulty 
-		 * cases ?
-		 */
+		text3d = (text3dstruct*) NULL;
 #ifdef USE_BLANK
                 (void) fprintf(stderr,
                                "%s: jumping to 'blank' mode.\n", MI_NAME(mi));
@@ -790,7 +803,7 @@ init_text3d(ModeInfo * mi)
 		fprintf( stderr, "%s: unable to open True Type font %s !\n", MI_NAME(mi), fontfile);
 		delete tp->face;
 		(void) free((void *) text3d);
-		text3d = NULL;
+		text3d = (text3dstruct*) NULL;
 #ifdef USE_BLANK
                 (void) fprintf(stderr,
                                "%s: jumping to 'blank' mode.\n", MI_NAME(mi));
@@ -903,7 +916,7 @@ release_text3d(ModeInfo * mi)
 				delete tp->face;
                 }
 		(void) free((void *) text3d);
-		text3d = NULL;
+		text3d = (text3dstruct*) NULL;
 	}
 #ifdef USE_BLANK
 	else
@@ -940,4 +953,4 @@ change_text3d(ModeInfo * mi)
 	glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(tp->glx_context));
 }
 
-#endif /* USE_GL */
+#endif /* MODE_text3d */
