@@ -84,6 +84,8 @@ static const char sccsid[] = "@(#)maze.c	4.07 97/11/24 xlockmore";
 #endif /* STANDALONE */
 #include "iostuff.h"
 
+#ifdef MODE_maze
+
 ModeSpecOpt maze_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -884,3 +886,5 @@ refresh_maze(ModeInfo * mi)
 	}
 	mp->solving = 0;
 }
+
+#endif /* MODE_maze */
