@@ -60,6 +60,8 @@ static const char sccsid[] = "@(#)munch.c 4.07 97/11/24 xlockmore";
 #include "xlock.h"		/* from the xlockmore distribution */
 #endif /* !STANDALONE */
 
+#ifdef MODE_munch
+
 ModeSpecOpt munch_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -258,3 +260,5 @@ release_munch(ModeInfo * mi)
 		munches = NULL;
 	}
 }
+
+#endif /* MODE_munch */
