@@ -61,6 +61,8 @@ static const char sccsid[] = "@(#)shape.c	4.07 97/11/24 xlockmore";
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
+#ifdef MODE_shape
+
 #ifndef STIPPLING
 /*-
  * For Linux (others, Intel based?) this could be deadly for the client.
@@ -410,3 +412,5 @@ refresh_shape(ModeInfo * mi)
 {
 	MI_CLEARWINDOW(mi);
 }
+
+#endif /* MODE_shape */
