@@ -71,6 +71,8 @@ static const char sccsid[] = "@(#)sphere.c	4.07 97/11/24 xlockmore";
 #include "xlock.h"		/* from the xlockmore distribution */
 #endif /* !STANDALONE */
 
+#ifdef MODE_sphere
+
 ModeSpecOpt sphere_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -287,3 +289,5 @@ refresh_sphere(ModeInfo * mi)
 
 	sp->x = -sp->radius;
 }
+
+#endif /* MODE_sphere */
