@@ -11,9 +11,7 @@ static char *LockProcs[] =
 "bounce",
 "braid",
 "bubble",
-#ifdef USE_GL
 "bubble3d",
-#endif
 "bug",
 #ifdef USE_GL
 "cage",
@@ -106,6 +104,7 @@ static char *LockProcs[] =
 #endif
 "swarm",
 "swirl",
+"tetris",
 "thornbird",
 "triangle",
 "tube",
@@ -116,6 +115,7 @@ static char *LockProcs[] =
 "wire",
 "world",
 "worm",
+"xjack",
 "blank",
 
 #ifdef USE_BOMB
