@@ -2,7 +2,7 @@
 #define __XLOCK_MODE_H__
 
 /*-
- * @(#)mode.h	4.10 98/04/23 xlockmore
+ * @(#)mode.h	4.13 99/02/14 xlockmore
  *
  * mode.h - mode management for xlock, the X Window System lockscreen.
  *
@@ -117,6 +117,9 @@
 
 #include "screenhack.h"
 
+#ifdef __cplusplus
+  extern "C" {
+#endif
 typedef struct ModeInfo {
 	Display    *dpy;
 	Window      window;
@@ -181,13 +184,17 @@ extern void xlockmore_screenhack(Display * dpy, Window window,
 				 void        (*hack_init) (ModeInfo *),
 				 void        (*hack_draw) (ModeInfo *),
 				 void        (*hack_free) (ModeInfo *));
-
 #ifdef USE_GL
 extern Visual *get_gl_visual(Screen * screen, char *name, char *class);
-
+#endif
+#ifdef __cplusplus
+  }
 #endif
 
 #else /* STANDALONE */
+#ifdef __cplusplus
+  extern "C" {
+#endif
 struct LockStruct_s;
 struct ModeInfo_s;
 
@@ -245,7 +252,6 @@ typedef struct {
 	Window      root;	/* convenience pointer to the root window */
 #ifdef USE_BUTTON_LOGOUT
 	Window      button;
-
 #endif
 	GC          gc;		/* graphics context for animation */
 	GC          textgc;	/* graphics context used for text rendering */
@@ -260,6 +266,9 @@ typedef struct {
 	unsigned long none_pixel, both_pixel;
 	XWindowChanges fullsizeconfigure;
 	mboxInfo    mb;
+#ifdef USE_UNSTABLE
+	Pixmap	    root_pixmap;	
+#endif
 } ScreenInfo;
 
 typedef struct {
@@ -277,6 +286,9 @@ typedef struct {
 	Bool        is_drawn;	/*Indicates that enough is drawn for special *
 				 *  erase                                    */
 } WindowInfo;
+#ifdef __cplusplus
+  }
+#endif
 
 #define WI_FLAG_INFO_INITTED	0x001	/* private state flag */
 #define WI_FLAG_ICONIC		0x002
@@ -293,6 +305,9 @@ typedef struct {
 #define WI_FLAG_MOUSE		0x1000
 #define WI_FLAG_JUST_INITTED	0x2000	/* private state flag */
 
+#ifdef __cplusplus
+  extern "C" {
+#endif
 typedef struct {
 	long        pause;	/* output, set by mode */
 	long        delay;	/* inputs, current settings */
@@ -310,6 +325,9 @@ typedef struct ModeInfo_s {
 	RunInfo     runinfo;
 	struct LockStruct_s *lockstruct;
 } ModeInfo;
+#ifdef __cplusplus
+  }
+#endif
 
 /* -------------------------------------------------------------------- */
 
@@ -378,6 +396,9 @@ typedef struct ModeInfo_s {
 #define MI_NONE_COLOR(mi)	((mi)->screeninfo->none_pixel)	/* -install */
 #define MI_RIGHT_COLOR(mi)	((mi)->screeninfo->right_pixel)
 #define MI_LEFT_COLOR(mi)	((mi)->screeninfo->left_pixel)
+#ifdef USE_UNSTABLE
+#define MI_ROOT_PIXMAP(mi)	((mi)->screeninfo->root_pixmap)
+#endif
 
 #define MI_DELAY(mi)		((mi)->runinfo.delay)
 #define MI_COUNT(mi)		((mi)->runinfo.count)
@@ -409,8 +430,14 @@ typedef struct ModeInfo_s {
  */
 #endif
 
-extern void
-            erase_full_window(ModeInfo * mi, GC erase_gc, unsigned long pixel);
+#ifdef __cplusplus
+  extern "C" {
+#endif
+extern void modeDescription(ModeInfo * mi);
+extern void erase_full_window(ModeInfo * mi, GC erase_gc, unsigned long pixel);
+#ifdef __cplusplus
+  }
+#endif
 
 #if 0
 #define MI_CLEARWINDOWCOLORMAP(mi, gc, pixel) \
@@ -444,6 +471,9 @@ extern void
 
 /* -------------------------------------------------------------------- */
 
+#ifdef __cplusplus
+  extern "C" {
+#endif
 extern HookProc call_init_hook;
 extern HookProc call_callback_hook;
 extern HookProc call_release_hook;
@@ -454,630 +484,929 @@ extern void set_default_mode(LockStruct *);
 extern void release_last_mode(ModeInfo *);
 
 /* -------------------------------------------------------------------- */
+
+/* comment out following defines to remove modes */
+#ifdef USE_GL
+#define MODE_atlantis
+#define MODE_cage
+#define MODE_gears
+#define MODE_moebius
+#define MODE_morph3d
+#define MODE_pipes
+#define MODE_rubik
+#define MODE_sproingies
+#define MODE_stairs
+#define MODE_superquadrics
+#ifdef HAVE_CXX
+#define MODE_bubble3d
+#define MODE_invert
+#if defined( HAVE_TTF ) && defined( HAVE_GLTT ) && defined( USE_UNSTABLE )
+#define MODE_text3d
+#endif
+#endif
+#if defined( USE_XPM ) || defined( USE_XPMINC )
+#define MODE_lament
+#endif
+#endif
+#if defined( USE_XPM ) || defined( USE_XPMINC )
+#define MODE_cartoon
+#endif
+#ifdef USE_UNSTABLE
+#define MODE_decay
+#define MODE_lyapunov
+#endif
+#define MODE_ant
+#define MODE_ball
+#define MODE_bat
+#define MODE_blot
+#define MODE_bouboule
+#define MODE_bounce
+#define MODE_braid
+#define MODE_bubble
+#define MODE_bug
+#define MODE_clock
+#define MODE_coral
+#define MODE_crystal
+#define MODE_daisy
+#define MODE_dclock
+#define MODE_deco
+#define MODE_demon
+#define MODE_dilemma
+#define MODE_discrete
+#define MODE_drift
+#define MODE_eyes
+#define MODE_fadeplot
+#define MODE_flag
+#define MODE_flame
+#define MODE_flow
+#define MODE_forest
+#define MODE_galaxy
+#define MODE_goop
+#define MODE_grav
+#define MODE_helix
+#define MODE_hop
+#define MODE_hyper
+#define MODE_ico
+#define MODE_ifs
+#define MODE_image
+#define MODE_julia
+#define MODE_kaleid
+#define MODE_kumppa
+#define MODE_laser
+#define MODE_life
+#define MODE_life1d
+#define MODE_life3d
+#define MODE_lightning
+#define MODE_lisa
+#define MODE_lissie
+#define MODE_loop
+#define MODE_mandelbrot
+#define MODE_marquee
+#define MODE_maze
+#define MODE_mountain
+#define MODE_munch
+#define MODE_nose
+#define MODE_pacman
+#define MODE_penrose
+#define MODE_petal
+#define MODE_puzzle
+#define MODE_pyro
+#define MODE_qix
+#define MODE_roll
+#define MODE_rotor
+#define MODE_shape
+#define MODE_sierpinski
+#define MODE_slip
+#define MODE_sphere
+#define MODE_spiral
+#define MODE_spline
+#define MODE_star
+#define MODE_starfish
+#define MODE_strange
+#define MODE_swarm
+#define MODE_swirl
+#define MODE_tetris
+#define MODE_thornbird
+#define MODE_triangle
+#define MODE_tube
+#define MODE_turtle
+#define MODE_vines
+#define MODE_voters
+#define MODE_wator
+#define MODE_wire
+#define MODE_world
+#define MODE_worm
+#define MODE_xjack
+
+#if USE_BOMB
+#define MODE_bomb
+#endif
+
 #ifndef USE_MODULES
 
+#ifdef MODE_ant
 extern ModeHook init_ant;
 extern ModeHook draw_ant;
 extern ModeHook release_ant;
 extern ModeHook refresh_ant;
 extern ModeSpecOpt ant_opts;
+#endif
 
-#ifdef USE_GL
+#ifdef MODE_atlantis
 extern ModeHook init_atlantis;
 extern ModeHook draw_atlantis;
 extern ModeHook release_atlantis;
 extern ModeHook refresh_atlantis;
 extern ModeHook change_atlantis;
 extern ModeSpecOpt atlantis_opts;
-
 #endif
 
+#ifdef MODE_ball
 extern ModeHook init_ball;
 extern ModeHook draw_ball;
 extern ModeHook release_ball;
 extern ModeHook refresh_ball;
 extern ModeSpecOpt ball_opts;
+#endif
 
+#ifdef MODE_bat
 extern ModeHook init_bat;
 extern ModeHook draw_bat;
 extern ModeHook release_bat;
 extern ModeHook refresh_bat;
 extern ModeSpecOpt bat_opts;
+#endif
 
+#ifdef MODE_blot
 extern ModeHook init_blot;
 extern ModeHook draw_blot;
 extern ModeHook release_blot;
 extern ModeHook refresh_blot;
 extern ModeSpecOpt blot_opts;
+#endif
 
+#ifdef MODE_bouboule
 extern ModeHook init_bouboule;
 extern ModeHook draw_bouboule;
 extern ModeHook release_bouboule;
 extern ModeHook refresh_bouboule;
 extern ModeSpecOpt bouboule_opts;
+#endif
 
+#ifdef MODE_bounce
 extern ModeHook init_bounce;
 extern ModeHook draw_bounce;
 extern ModeHook release_bounce;
 extern ModeHook refresh_bounce;
 extern ModeSpecOpt bounce_opts;
+#endif
 
+#ifdef MODE_braid
 extern ModeHook init_braid;
 extern ModeHook draw_braid;
 extern ModeHook release_braid;
 extern ModeHook refresh_braid;
 extern ModeSpecOpt braid_opts;
+#endif
 
+#ifdef MODE_bubble
 extern ModeHook init_bubble;
 extern ModeHook draw_bubble;
 extern ModeHook release_bubble;
 extern ModeHook refresh_bubble;
 extern ModeSpecOpt bubble_opts;
+#endif
 
-#ifdef USE_GL
+#ifdef MODE_bubble3d
 extern ModeHook init_bubble3d;
 extern ModeHook draw_bubble3d;
 extern ModeHook release_bubble3d;
 extern ModeHook change_bubble3d;
 extern ModeSpecOpt bubble3d_opts;
-
 #endif
 
+#ifdef MODE_bug
 extern ModeHook init_bug;
 extern ModeHook draw_bug;
 extern ModeHook release_bug;
 extern ModeHook refresh_bug;
 extern ModeSpecOpt bug_opts;
+#endif
 
-#ifdef USE_GL
+#ifdef MODE_cage
 extern ModeHook init_cage;
 extern ModeHook draw_cage;
 extern ModeHook release_cage;
 extern ModeHook change_cage;
 extern ModeSpecOpt cage_opts;
-
 #endif
 
-#if defined( USE_XPM ) || defined( USE_XPMINC )
+#ifdef MODE_cartoon
 extern ModeHook init_cartoon;
 extern ModeHook draw_cartoon;
 extern ModeHook release_cartoon;
 extern ModeSpecOpt cartoon_opts;
-
 #endif
 
+#ifdef MODE_clock
 extern ModeHook init_clock;
 extern ModeHook draw_clock;
 extern ModeHook release_clock;
 extern ModeHook refresh_clock;
 extern ModeSpecOpt clock_opts;
+#endif
 
+#ifdef MODE_coral
 extern ModeHook init_coral;
 extern ModeHook draw_coral;
 extern ModeHook release_coral;
 extern ModeHook refresh_coral;
 extern ModeSpecOpt coral_opts;
+#endif
 
+#ifdef MODE_crystal
 extern ModeHook init_crystal;
 extern ModeHook draw_crystal;
 extern ModeHook release_crystal;
 extern ModeHook refresh_crystal;
 extern ModeSpecOpt crystal_opts;
+#endif
 
+#ifdef MODE_daisy
 extern ModeHook init_daisy;
 extern ModeHook draw_daisy;
 extern ModeHook release_daisy;
 extern ModeHook refresh_daisy;
 extern ModeSpecOpt daisy_opts;
+#endif
 
+#ifdef MODE_dclock
 extern ModeHook init_dclock;
 extern ModeHook draw_dclock;
 extern ModeHook release_dclock;
 extern ModeHook refresh_dclock;
 extern ModeSpecOpt dclock_opts;
+#endif
 
+#ifdef MODE_decay
+extern ModeHook init_decay;
+extern ModeHook draw_decay;
+extern ModeHook release_decay;
+extern ModeHook refresh_decay;
+extern ModeSpecOpt decay_opts;
+#endif
+
+#ifdef MODE_deco
 extern ModeHook init_deco;
 extern ModeHook draw_deco;
 extern ModeHook release_deco;
 extern ModeHook refresh_deco;
 extern ModeSpecOpt deco_opts;
+#endif
 
+#ifdef MODE_demon
 extern ModeHook init_demon;
 extern ModeHook draw_demon;
 extern ModeHook release_demon;
 extern ModeHook refresh_demon;
 extern ModeSpecOpt demon_opts;
+#endif
 
+#ifdef MODE_dilemma
 extern ModeHook init_dilemma;
 extern ModeHook draw_dilemma;
 extern ModeHook release_dilemma;
 extern ModeHook refresh_dilemma;
 extern ModeSpecOpt dilemma_opts;
+#endif
 
+#ifdef MODE_discrete
 extern ModeHook init_discrete;
 extern ModeHook draw_discrete;
 extern ModeHook release_discrete;
 extern ModeHook refresh_discrete;
 extern ModeHook change_discrete;
 extern ModeSpecOpt discrete_opts;
+#endif
 
+#ifdef MODE_drift
 extern ModeHook init_drift;
 extern ModeHook draw_drift;
 extern ModeHook release_drift;
 extern ModeHook refresh_drift;
 extern ModeSpecOpt drift_opts;
+#endif
 
+#ifdef MODE_eyes
 extern ModeHook init_eyes;
 extern ModeHook draw_eyes;
 extern ModeHook release_eyes;
 extern ModeHook refresh_eyes;
 extern ModeSpecOpt eyes_opts;
+#endif
 
+#ifdef MODE_fadeplot
 extern ModeHook init_fadeplot;
 extern ModeHook draw_fadeplot;
 extern ModeHook release_fadeplot;
 extern ModeHook refresh_fadeplot;
 extern ModeSpecOpt fadeplot_opts;
+#endif
 
+#ifdef MODE_flag
 extern ModeHook init_flag;
 extern ModeHook draw_flag;
 extern ModeHook release_flag;
 extern ModeHook refresh_flag;
 extern ModeSpecOpt flag_opts;
+#endif
 
+#ifdef MODE_flame
 extern ModeHook init_flame;
 extern ModeHook draw_flame;
 extern ModeHook release_flame;
 extern ModeHook refresh_flame;
 extern ModeSpecOpt flame_opts;
+#endif
 
+#ifdef MODE_flow
 extern ModeHook init_flow;
 extern ModeHook draw_flow;
 extern ModeHook release_flow;
 extern ModeHook refresh_flow;
 extern ModeHook change_flow;
 extern ModeSpecOpt flow_opts;
+#endif
 
+#ifdef MODE_forest
 extern ModeHook init_forest;
 extern ModeHook draw_forest;
 extern ModeHook release_forest;
 extern ModeHook refresh_forest;
 extern ModeSpecOpt forest_opts;
+#endif
 
-extern ModeHook init_fusee;
-extern ModeHook draw_fusee;
-extern ModeHook release_fusee;
-extern ModeHook refresh_fusee;
-extern ModeSpecOpt fusee_opts;
-
+#ifdef MODE_galaxy
 extern ModeHook init_galaxy;
 extern ModeHook draw_galaxy;
 extern ModeHook release_galaxy;
 extern ModeHook refresh_galaxy;
 extern ModeSpecOpt galaxy_opts;
+#endif
 
-#ifdef USE_GL
+#ifdef MODE_gears
 extern ModeHook init_gears;
 extern ModeHook draw_gears;
 extern ModeHook release_gears;
 extern ModeSpecOpt gears_opts;
-
 #endif
 
+#ifdef MODE_goop
 extern ModeHook init_goop;
 extern ModeHook draw_goop;
 extern ModeHook release_goop;
 extern ModeSpecOpt goop_opts;
+#endif
 
+#ifdef MODE_grav
 extern ModeHook init_grav;
 extern ModeHook draw_grav;
 extern ModeHook release_grav;
 extern ModeHook refresh_grav;
 extern ModeSpecOpt grav_opts;
+#endif
 
+#ifdef MODE_helix
 extern ModeHook init_helix;
 extern ModeHook draw_helix;
 extern ModeHook release_helix;
 extern ModeHook refresh_helix;
 extern ModeSpecOpt helix_opts;
+#endif
 
+#ifdef MODE_hop
 extern ModeHook init_hop;
 extern ModeHook draw_hop;
 extern ModeHook release_hop;
 extern ModeHook refresh_hop;
 extern ModeSpecOpt hop_opts;
+#endif
 
+#ifdef MODE_hyper
 extern ModeHook init_hyper;
 extern ModeHook draw_hyper;
 extern ModeHook release_hyper;
 extern ModeHook refresh_hyper;
 extern ModeHook change_hyper;
 extern ModeSpecOpt hyper_opts;
+#endif
 
+#ifdef MODE_ico
 extern ModeHook init_ico;
 extern ModeHook draw_ico;
 extern ModeHook release_ico;
 extern ModeHook refresh_ico;
 extern ModeHook change_ico;
 extern ModeSpecOpt ico_opts;
+#endif
 
+#ifdef MODE_ifs
 extern ModeHook init_ifs;
 extern ModeHook draw_ifs;
 extern ModeHook release_ifs;
 extern ModeSpecOpt ifs_opts;
+#endif
 
+#ifdef MODE_image
 extern ModeHook init_image;
 extern ModeHook draw_image;
 extern ModeHook release_image;
 extern ModeHook refresh_image;
 extern ModeSpecOpt image_opts;
+#endif
 
+#ifdef MODE_invert
+extern ModeHook init_invert;
+extern ModeHook draw_invert;
+extern ModeHook release_invert;
+extern ModeSpecOpt invert_opts;
+#endif
+
+#ifdef MODE_julia
 extern ModeHook init_julia;
 extern ModeHook draw_julia;
 extern ModeHook release_julia;
 extern ModeHook refresh_julia;
 extern ModeSpecOpt julia_opts;
+#endif
 
+#ifdef MODE_kaleid
 extern ModeHook init_kaleid;
 extern ModeHook draw_kaleid;
 extern ModeHook release_kaleid;
 extern ModeHook refresh_kaleid;
 extern ModeSpecOpt kaleid_opts;
+#endif
 
+#ifdef MODE_kumppa
 extern ModeHook init_kumppa;
 extern ModeHook draw_kumppa;
 extern ModeHook release_kumppa;
 extern ModeHook refresh_kumppa;
 extern ModeSpecOpt kumppa_opts;
+#endif
 
-#if defined( USE_GL ) && (defined( USE_XPM ) || defined( USE_XPMINC )) && defined( USE_UNSTABLE )
+#ifdef MODE_lament
 extern ModeHook init_lament;
 extern ModeHook draw_lament;
 extern ModeHook release_lament;
 extern ModeHook change_lament;
 extern ModeSpecOpt lament_opts;
-
 #endif
 
+#ifdef MODE_laser
 extern ModeHook init_laser;
 extern ModeHook draw_laser;
 extern ModeHook release_laser;
 extern ModeHook refresh_laser;
 extern ModeSpecOpt laser_opts;
+#endif
 
+#ifdef MODE_life
 extern ModeHook init_life;
 extern ModeHook draw_life;
 extern ModeHook release_life;
 extern ModeHook refresh_life;
 extern ModeHook change_life;
 extern ModeSpecOpt life_opts;
+#endif
 
+#ifdef MODE_life1d
 extern ModeHook init_life1d;
 extern ModeHook draw_life1d;
 extern ModeHook release_life1d;
 extern ModeHook refresh_life1d;
 extern ModeSpecOpt life1d_opts;
+#endif
 
+#ifdef MODE_life3d
 extern ModeHook init_life3d;
 extern ModeHook draw_life3d;
 extern ModeHook release_life3d;
 extern ModeHook refresh_life3d;
 extern ModeHook change_life3d;
 extern ModeSpecOpt life3d_opts;
+#endif
 
+#ifdef MODE_lightning
 extern ModeHook init_lightning;
 extern ModeHook draw_lightning;
 extern ModeHook release_lightning;
 extern ModeHook refresh_lightning;
 extern ModeSpecOpt lightning_opts;
+#endif
 
+#ifdef MODE_lisa
 extern ModeHook init_lisa;
 extern ModeHook draw_lisa;
 extern ModeHook release_lisa;
 extern ModeHook refresh_lisa;
 extern ModeHook change_lisa;
 extern ModeSpecOpt lisa_opts;
+#endif
 
+#ifdef MODE_lissie
 extern ModeHook init_lissie;
 extern ModeHook draw_lissie;
 extern ModeHook release_lissie;
 extern ModeHook refresh_lissie;
 extern ModeSpecOpt lissie_opts;
+#endif
 
+#ifdef MODE_loop
 extern ModeHook init_loop;
 extern ModeHook draw_loop;
 extern ModeHook release_loop;
 extern ModeHook refresh_loop;
 extern ModeSpecOpt loop_opts;
+#endif
 
+#ifdef MODE_lyapunov
+extern ModeHook init_lyapunov;
+extern ModeHook draw_lyapunov;
+extern ModeHook release_lyapunov;
+extern ModeHook refresh_lyapunov;
+extern ModeSpecOpt lyapunov_opts;
+#endif
+
+#ifdef MODE_mandelbrot
 extern ModeHook init_mandelbrot;
 extern ModeHook draw_mandelbrot;
 extern ModeHook release_mandelbrot;
 extern ModeHook refresh_mandelbrot;
 extern ModeSpecOpt mandelbrot_opts;
+#endif
 
+#ifdef MODE_marquee
 extern ModeHook init_marquee;
 extern ModeHook draw_marquee;
 extern ModeHook release_marquee;
 extern ModeSpecOpt marquee_opts;
+#endif
 
+#ifdef MODE_maze
 extern ModeHook init_maze;
 extern ModeHook draw_maze;
 extern ModeHook release_maze;
 extern ModeHook refresh_maze;
 extern ModeSpecOpt maze_opts;
+#endif
 
-#ifdef USE_GL
+#ifdef MODE_moebius
 extern ModeHook init_moebius;
 extern ModeHook draw_moebius;
 extern ModeHook release_moebius;
 extern ModeHook change_moebius;
 extern ModeSpecOpt moebius_opts;
+#endif
 
+#ifdef MODE_morph3d
 extern ModeHook init_morph3d;
 extern ModeHook draw_morph3d;
 extern ModeHook release_morph3d;
 extern ModeHook change_morph3d;
 extern ModeSpecOpt morph3d_opts;
-
 #endif
 
+#ifdef MODE_mountain
 extern ModeHook init_mountain;
 extern ModeHook draw_mountain;
 extern ModeHook release_mountain;
 extern ModeHook refresh_mountain;
 extern ModeSpecOpt mountain_opts;
+#endif
 
+#ifdef MODE_munch
 extern ModeHook init_munch;
 extern ModeHook draw_munch;
 extern ModeHook release_munch;
 extern ModeSpecOpt munch_opts;
+#endif
 
+#ifdef MODE_nose
 extern ModeHook init_nose;
 extern ModeHook draw_nose;
 extern ModeHook release_nose;
 extern ModeHook refresh_nose;
 extern ModeSpecOpt nose_opts;
+#endif
 
+#ifdef MODE_pacman
 extern ModeHook init_pacman;
 extern ModeHook draw_pacman;
 extern ModeHook release_pacman;
 extern ModeHook refresh_pacman;
 extern ModeSpecOpt pacman_opts;
+#endif
 
+#ifdef MODE_penrose
 extern ModeHook init_penrose;
 extern ModeHook draw_penrose;
 extern ModeHook release_penrose;
 
 #if 0
 extern ModeHook refresh_penrose;	/* Needed */
-
 #endif
 extern ModeSpecOpt penrose_opts;
+#endif
 
+#ifdef MODE_petal
 extern ModeHook init_petal;
 extern ModeHook draw_petal;
 extern ModeHook release_petal;
 extern ModeHook refresh_petal;
 extern ModeSpecOpt petal_opts;
+#endif
 
-#ifdef USE_GL
+#ifdef MODE_pipes
 extern ModeHook init_pipes;
 extern ModeHook draw_pipes;
 extern ModeHook release_pipes;
 extern ModeHook refresh_pipes;
 extern ModeHook change_pipes;
 extern ModeSpecOpt pipes_opts;
-
 #endif
 
+#ifdef MODE_puzzle
 extern ModeHook init_puzzle;
 extern ModeHook draw_puzzle;
 extern ModeHook release_puzzle;
 
 #if 0
 extern ModeHook refresh_puzzle;	/* Needed */
-
 #endif
 extern ModeSpecOpt puzzle_opts;
+#endif
 
+#ifdef MODE_pyro
 extern ModeHook init_pyro;
 extern ModeHook draw_pyro;
 extern ModeHook release_pyro;
 extern ModeHook refresh_pyro;
 extern ModeSpecOpt pyro_opts;
+#endif
 
+#ifdef MODE_qix
 extern ModeHook init_qix;
 extern ModeHook draw_qix;
 extern ModeHook release_qix;
 extern ModeHook refresh_qix;
 extern ModeSpecOpt qix_opts;
+#endif
 
+#ifdef MODE_roll
 extern ModeHook init_roll;
 extern ModeHook draw_roll;
 extern ModeHook release_roll;
 extern ModeHook refresh_roll;
 extern ModeSpecOpt roll_opts;
+#endif
 
+#ifdef MODE_rotor
 extern ModeHook init_rotor;
 extern ModeHook draw_rotor;
 extern ModeHook release_rotor;
 extern ModeHook refresh_rotor;
 extern ModeSpecOpt rotor_opts;
+#endif
 
-#ifdef USE_GL
+#ifdef MODE_rubik
 extern ModeHook init_rubik;
 extern ModeHook draw_rubik;
 extern ModeHook release_rubik;
 extern ModeHook change_rubik;
 extern ModeSpecOpt rubik_opts;
-
 #endif
 
+#ifdef MODE_shape
 extern ModeHook init_shape;
 extern ModeHook draw_shape;
 extern ModeHook release_shape;
 extern ModeHook refresh_shape;
 extern ModeSpecOpt shape_opts;
+#endif
 
+#ifdef MODE_sierpinski
 extern ModeHook init_sierpinski;
 extern ModeHook draw_sierpinski;
 extern ModeHook release_sierpinski;
 extern ModeHook refresh_sierpinski;
 extern ModeSpecOpt sierpinski_opts;
+#endif
 
+#ifdef MODE_slip
 extern ModeHook init_slip;
 extern ModeHook draw_slip;
 extern ModeHook release_slip;
 
 #if 0
 extern ModeHook refresh_slip;	/* Probably not practical */
-
 #endif
 extern ModeSpecOpt slip_opts;
+#endif
 
+#ifdef MODE_sphere
 extern ModeHook init_sphere;
 extern ModeHook draw_sphere;
 extern ModeHook release_sphere;
 extern ModeHook refresh_sphere;
 extern ModeSpecOpt sphere_opts;
+#endif
 
+#ifdef MODE_spiral
 extern ModeHook init_spiral;
 extern ModeHook draw_spiral;
 extern ModeHook release_spiral;
 extern ModeHook refresh_spiral;
 extern ModeSpecOpt spiral_opts;
+#endif
 
+#ifdef MODE_spline
 extern ModeHook init_spline;
 extern ModeHook draw_spline;
 extern ModeHook release_spline;
 extern ModeHook refresh_spline;
 extern ModeSpecOpt spline_opts;
+#endif
 
-#ifdef USE_GL
+#ifdef MODE_sproingies
 extern ModeHook init_sproingies;
 extern ModeHook draw_sproingies;
 extern ModeHook release_sproingies;
 extern ModeHook refresh_sproingies;
 extern ModeSpecOpt sproingies_opts;
+#endif
 
+#ifdef MODE_stairs
 extern ModeHook init_stairs;
 extern ModeHook draw_stairs;
 extern ModeHook release_stairs;
 extern ModeHook refresh_stairs;
 extern ModeHook change_stairs;
 extern ModeSpecOpt stairs_opts;
-
 #endif
 
+#ifdef MODE_star
 extern ModeHook init_star;
 extern ModeHook draw_star;
 extern ModeHook release_star;
 extern ModeHook refresh_star;
 extern ModeSpecOpt star_opts;
+#endif
 
+#ifdef MODE_starfish
 extern ModeHook init_starfish;
 extern ModeHook draw_starfish;
 extern ModeHook release_starfish;
 extern ModeHook refresh_starfish;
 extern ModeSpecOpt starfish_opts;
+#endif
 
+#ifdef MODE_strange
 extern ModeHook init_strange;
 extern ModeHook draw_strange;
 extern ModeHook release_strange;
 extern ModeSpecOpt strange_opts;
+#endif
 
-#ifdef USE_GL
+#ifdef MODE_superquadrics
 extern ModeHook init_superquadrics;
 extern ModeHook draw_superquadrics;
 extern ModeHook release_superquadrics;
 extern ModeHook refresh_superquadrics;
 extern ModeSpecOpt superquadrics_opts;
-
 #endif
 
+#ifdef MODE_swarm
 extern ModeHook init_swarm;
 extern ModeHook draw_swarm;
 extern ModeHook release_swarm;
 extern ModeHook refresh_swarm;
 extern ModeSpecOpt swarm_opts;
+#endif
 
+#ifdef MODE_swirl
 extern ModeHook init_swirl;
 extern ModeHook draw_swirl;
 extern ModeHook release_swirl;
 extern ModeHook refresh_swirl;
 extern ModeSpecOpt swirl_opts;
+#endif
 
-#if defined( USE_GL ) && defined( USE_TEXT )
+#ifdef MODE_tetris
+extern ModeHook init_tetris;
+extern ModeHook draw_tetris;
+extern ModeHook release_tetris;
+extern ModeHook refresh_tetris;
+extern ModeSpecOpt tetris_opts;
+#endif
+
+#ifdef MODE_text3d
 extern ModeHook init_text3d;
 extern ModeHook draw_text3d;
 extern ModeHook release_text3d;
 extern ModeHook refresh_text3d;
 extern ModeHook change_text3d;
 extern ModeSpecOpt text3d_opts;
-
 #endif
 
+#ifdef MODE_thornbird
 extern ModeHook init_thornbird;
 extern ModeHook draw_thornbird;
 extern ModeHook release_thornbird;
 extern ModeHook refresh_thornbird;
 extern ModeHook change_thornbird;
 extern ModeSpecOpt thornbird_opts;
+#endif
 
+#ifdef MODE_triangle
 extern ModeHook init_triangle;
 extern ModeHook draw_triangle;
 extern ModeHook release_triangle;
 extern ModeHook refresh_triangle;
 extern ModeSpecOpt triangle_opts;
+#endif
 
+#ifdef MODE_tube
 extern ModeHook init_tube;
 extern ModeHook draw_tube;
 extern ModeHook release_tube;
 extern ModeHook refresh_tube;
 extern ModeSpecOpt tube_opts;
+#endif
 
+#ifdef MODE_turtle
 extern ModeHook init_turtle;
 extern ModeHook draw_turtle;
 extern ModeHook release_turtle;
 extern ModeHook refresh_turtle;
 extern ModeSpecOpt turtle_opts;
+#endif
 
+#ifdef MODE_vines
 extern ModeHook init_vines;
 extern ModeHook draw_vines;
 extern ModeHook release_vines;
 extern ModeHook refresh_vines;
 extern ModeSpecOpt vines_opts;
+#endif
 
+#ifdef MODE_voters
 extern ModeHook init_voters;
 extern ModeHook draw_voters;
 extern ModeHook release_voters;
 extern ModeHook refresh_voters;
 extern ModeSpecOpt voters_opts;
+#endif
 
+#ifdef MODE_wator
 extern ModeHook init_wator;
 extern ModeHook draw_wator;
 extern ModeHook release_wator;
 extern ModeHook refresh_wator;
 extern ModeSpecOpt wator_opts;
+#endif
 
+#ifdef MODE_wire
 extern ModeHook init_wire;
 extern ModeHook draw_wire;
 extern ModeHook release_wire;
 extern ModeHook refresh_wire;
 extern ModeSpecOpt wire_opts;
+#endif
 
+#ifdef MODE_world
 extern ModeHook init_world;
 extern ModeHook draw_world;
 extern ModeHook release_world;
 extern ModeHook refresh_world;
 extern ModeSpecOpt world_opts;
+#endif
 
+#ifdef MODE_worm
 extern ModeHook init_worm;
 extern ModeHook draw_worm;
 extern ModeHook release_worm;
 extern ModeHook refresh_worm;
 extern ModeSpecOpt worm_opts;
+#endif
+
+#ifdef MODE_xjack
+extern ModeHook init_xjack;
+extern ModeHook draw_xjack;
+extern ModeHook release_xjack;
+extern ModeSpecOpt xjack_opts;
+#endif
 
 extern ModeHook init_blank;
 extern ModeHook draw_blank;
@@ -1085,14 +1414,13 @@ extern ModeHook release_blank;
 extern ModeHook refresh_blank;
 extern ModeSpecOpt blank_opts;
 
-#ifdef USE_BOMB
+#ifdef MODE_bomb
 extern ModeHook init_bomb;
 extern ModeHook draw_bomb;
 extern ModeHook release_bomb;
 extern ModeHook refresh_bomb;
 extern ModeHook change_bomb;
 extern ModeSpecOpt bomb_opts;
-
 #endif
 
 extern ModeHook init_random;
@@ -1116,6 +1444,9 @@ extern void **LoadedModules;	/* save handles on loaded modules for closing */
 
 extern int  numprocs;
 
+#ifdef __cplusplus
+  }
+#endif
 
 #endif /* STANDALONE */
 /* -------------------------------------------------------------------- */
