@@ -11,6 +11,8 @@ static const char sccsid[] = "@(#)passwd.c	4.02 97/04/01 xlockmore";
  * Revision History:
  *
  * Changes maintained by David Bagley <bagleyd@bigfoot.com>
+ * 18-Feb-99: allowroot option no longer ignored for PAM authentication.
+ *            Sven Paas <Sven.Paas@t-online.de>
  * 24-Jan-98: Updated PAM support and made it configure-able.
  *            Marc Ewing <marc@redhat.com>  Original PAM support from
  *            25-Jul-96 Michael K. Johnson <johnsonm@redhat.com>
@@ -33,6 +35,7 @@ static const char sccsid[] = "@(#)passwd.c	4.02 97/04/01 xlockmore";
 
 #include "xlock.h"
 #include "iostuff.h"
+#include "passwd.h"
 
 #ifdef VMS
 #include <str$routines.h>
@@ -42,7 +45,6 @@ static const char sccsid[] = "@(#)passwd.c	4.02 97/04/01 xlockmore";
 #define ROOT "root"
 #endif
 
-extern char *ProgramName;
 extern Bool allowroot;
 extern Bool inroot;
 extern Bool inwindow;
@@ -369,14 +371,14 @@ my_passwd_entry(void)
 	uid = (int) getuid();
 #ifndef SUNOS_ADJUNCT_PASSWD
 	{
-		char       *user = NULL;
+		char       *logname = NULL;
 
 		pw = 0;
-		user = getenv("LOGNAME");
-		if (!user)
-			user = getenv("USER");
-		if (user) {
-			pw = getpwnam(user);
+		logname = getenv("LOGNAME");
+		if (!logname)
+			logname = getenv("USER");
+		if (logname) {
+			pw = getpwnam(logname);
 			if (pw && (pw->pw_uid != uid))
 				pw = 0;
 		}
@@ -560,7 +562,7 @@ gpasskey(char *pass)
 }
 
 static void
-gpass()
+gpass(void)
 {
 	FILE       *fp;
 	extern char *cpasswd;
@@ -997,6 +999,11 @@ checkPasswd(char *buffer)
 	PAM_BAIL;
 	pam_error = pam_authenticate(pamh, 0);
 	if (pam_error != PAM_SUCCESS) {
+                if (!allowroot) {
+                        pam_end(pamh, 0);
+                        return 0;
+                }
+
 		/* Try as root; bail if no success there either */
 		pam_error = pam_set_item(pamh, PAM_USER, ROOT);
 		PAM_BAIL;
