@@ -196,6 +196,7 @@ static const char sccsid[] = "@(#)xlock.c	4.11 98/05/24 xlockmore";
 #include <string.h>
 #include "screenhack.h"
 #include "mode.h"
+#include "vis.h"
 
 #define countof(x) (sizeof((x))/sizeof(*(x)))
 
@@ -575,6 +576,7 @@ xlockmore_screenhack(Display * dpy, Window window,
 #include "color.h"
 #include "util.h"
 #include "iostuff.h"
+#include "passwd.h"
 #include <sys/stat.h>
 #include <signal.h>
 #include <errno.h>
@@ -637,8 +639,6 @@ struct itmlst_3 {
 
 extern char *getenv(const char *);
 extern void checkResources(void);
-extern void initPasswd(void);
-extern int  checkPasswd(char *);
 
 extern void defaultVisualInfo(Display * display, int screen);
 
@@ -698,6 +698,7 @@ extern Bool mono;
 extern Bool allowaccess;
 extern Bool allowroot;
 extern Bool debug;
+extern Bool description;
 extern Bool echokeys;
 extern Bool enablesaver;
 extern Bool fullrandom;
@@ -861,11 +862,11 @@ static XpmImage *nomail_xpmimg = NULL;
 
 #ifdef USE_VTLOCK
 	/* EL - RCS : for VT switching locking */
-extern int  vtlock;		/* Have to VT lock switching */
+extern int  vtlock;		/* Have to lock VT switching */
 extern int  vtlocked;		/* VT switching is locked */
 
 extern void dovtlock(void);	/* Actual do it */
-extern void dounvtlock(void);	/* & undo it functions */
+extern void dovtunlock(void);	/* & undo it functions */
 
 #endif
 
@@ -943,7 +944,7 @@ syslogStop(char *displayName)
 #endif
 
 void
-error(char *buf)
+error(const char *buf)
 {
 #if defined( HAVE_SYSLOG_H ) && defined( USE_SYSLOG )
 	extern Display *dsp;
@@ -1214,14 +1215,14 @@ mode_info(Display * display, int scrn, Window window, int iconic)
 void
 finish(Display * display, Bool closeDisplay)
 {
-	int         screen;
+	int         scrn;
 
-	for (screen = startscreen; screen < screens; screen++) {
-		if (Scr[screen].window != None) {
-			release_last_mode(mode_info(display, screen, Scr[screen].window, False));
+	for (scrn = startscreen; scrn < screens; scrn++) {
+		if (Scr[scrn].window != None) {
+			release_last_mode(mode_info(display, scrn, Scr[scrn].window, False));
 		}
-		if (Scr[screen].icon != None) {
-			release_last_mode(mode_info(display, screen, Scr[screen].icon, True));
+		if (Scr[scrn].icon != None) {
+			release_last_mode(mode_info(display, scrn, Scr[scrn].icon, True));
 		}
 	}
 #ifdef ORIGINAL_XPM_PATCH
@@ -1259,7 +1260,7 @@ finish(Display * display, Bool closeDisplay)
 #ifdef USE_VTLOCK
 	/* EL - RCS : Unlock VT switching */
 	if (vtlock && vtlocked)
-		dounvtlock();
+		dovtunlock();
 #endif
 }
 
@@ -1279,7 +1280,7 @@ xio_error(Display * d)
 /* Convenience function for drawing text */
 static void
 putText(Display * display, Window window, GC gc,
-	char *string, int bold, int left, int *px, int *py)
+	const char *string, int bold, int left, int *px, int *py)
 				/* which window */
 				/* gc */
 				/* text to write */
@@ -1922,25 +1923,25 @@ void
 modeDescription(ModeInfo * mi)
 {
 	int         left, x, y;
-	int         screen = MI_SCREEN(mi);
+	int         scrn = MI_SCREEN(mi);
 	XWindowAttributes xgwa;
 
-	(void) XGetWindowAttributes(dsp, Scr[screen].window, &xgwa);
+	(void) XGetWindowAttributes(dsp, Scr[scrn].window, &xgwa);
 
-	x = left = Scr[screen].iconpos.x;
-	y = Scr[screen].iconpos.y - font->ascent + font->descent + 2;
+	x = left = Scr[scrn].iconpos.x;
+	y = Scr[scrn].iconpos.y - font->ascent + font->descent + 2;
 
-	XSetForeground(dsp, Scr[screen].gc, Scr[screen].bg_pixel);
-	XFillRectangle(dsp, Scr[screen].window, Scr[screen].gc,
+	XSetForeground(dsp, Scr[scrn].gc, Scr[scrn].bg_pixel);
+	XFillRectangle(dsp, Scr[scrn].window, Scr[scrn].gc,
 		       x, y - font->ascent,
 		       xgwa.width - x, font->ascent + font->descent + 2);
 
-	putText(dsp, Scr[screen].window, Scr[screen].textgc, MI_NAME(mi),
+	putText(dsp, Scr[scrn].window, Scr[scrn].textgc, MI_NAME(mi),
 		True, left, &x, &y);
-	putText(dsp, Scr[screen].window, Scr[screen].textgc, ": ", True, left, &x, &y);
-	putText(dsp, Scr[screen].window, Scr[screen].textgc, MI_DESC(mi),
+	putText(dsp, Scr[scrn].window, Scr[scrn].textgc, ": ", True, left, &x, &y);
+	putText(dsp, Scr[scrn].window, Scr[scrn].textgc, MI_DESC(mi),
 		False, left, &x, &y);
-	putText(dsp, Scr[screen].window, Scr[screen].textgc, "\n", False, left, &x, &y);
+	putText(dsp, Scr[scrn].window, Scr[scrn].textgc, "\n", False, left, &x, &y);
 }
 
 static int
@@ -1985,7 +1986,8 @@ getPassword(void)
 	XMapWindow(dsp, Scr[screen].icon);
 	XRaiseWindow(dsp, Scr[screen].icon);
 
-	modeDescription(mi);
+	if (description)
+		modeDescription(mi);
 
 	x = left = Scr[screen].iconpos.x + iconwidth + font->max_bounds.width;
 	y = Scr[screen].iconpos.y + font->ascent;
@@ -2116,10 +2118,10 @@ getPassword(void)
 			mbxpm = mail_xpmimg;
 			mbi = &Scr[screen].mb.mail;
 		}
-		x = (DisplayWidth(dsp, screen) - mbxpm->width) / 2;
-		y = (Scr[screen].planpos.y - 5) - mbxpm->height;
 
 		if (mbxpm) {
+			x = (DisplayWidth(dsp, screen) - mbxpm->width) / 2;
+			y = (Scr[screen].planpos.y - 5) - mbxpm->height;
 			XCopyArea(dsp, mbi->pixmap,
 				  Scr[screen].window, Scr[screen].mb.mbgc,
 				  0, 0,
@@ -2127,20 +2129,22 @@ getPassword(void)
 		}
 #else
 		mailboxInfo *mbi;
-		int         x, y;
+		int         mbx, mby;
 
 		if (system(mailCmd)) {
 			mbi = &Scr[screen].mb.nomail;
 		} else {
 			mbi = &Scr[screen].mb.mail;
 		}
-		x = (DisplayWidth(dsp, screen) - mbi->width) / 2;
-		y = (Scr[screen].planpos.y - 5) - mbi->height;
-		XSetTSOrigin(dsp, Scr[screen].mb.mbgc, x, y);
-		XSetStipple(dsp, Scr[screen].mb.mbgc, mbi->pixmap);
-		XSetFillStyle(dsp, Scr[screen].mb.mbgc, FillOpaqueStippled);
-		XFillRectangle(dsp, Scr[screen].window, Scr[screen].mb.mbgc,
-			       x, y, mbi->width, mbi->height);
+		if (mbi) {
+			mbx = (DisplayWidth(dsp, screen) - mbi->width) / 2;
+			mby = (Scr[screen].planpos.y - 5) - mbi->height;
+			XSetTSOrigin(dsp, Scr[screen].mb.mbgc, mbx, mby);
+			XSetStipple(dsp, Scr[screen].mb.mbgc, mbi->pixmap);
+			XSetFillStyle(dsp, Scr[screen].mb.mbgc, FillOpaqueStippled);
+			XFillRectangle(dsp, Scr[screen].window, Scr[screen].mb.mbgc,
+			       mbx, mby, mbi->width, mbi->height);
+		}
 #endif
 	}
 	done = False;
@@ -2313,6 +2317,16 @@ justDisplay(Display * display)
 	int         not_done = True;
 	XEvent      event;
 
+#ifdef USE_VTLOCK
+        /* EL - RCS : lock VT switching */
+	/* 
+	 * I think it has to be done here or 'switch/restore' modes won't
+         * ever be usefull !
+	 */
+        if (!nolock && vtlock && !vtlocked)
+                dovtlock();
+#endif
+
 	for (screen = startscreen; screen < screens; screen++) {
 		call_init_hook((LockStruct *) NULL,
 		      mode_info(display, screen, Scr[screen].window, False));
@@ -2422,7 +2436,7 @@ static void
 sigcatch(int signum)
 {
 	ModeInfo   *mi = mode_info(dsp, startscreen, Scr[startscreen].window, False);
-	char       *name = (mi == NULL) ? "unknown" : MI_NAME(mi);
+	const char       *name = (mi == NULL) ? "unknown" : MI_NAME(mi);
 	char       *buf;
 
 
@@ -2440,7 +2454,7 @@ lockDisplay(Display * display, Bool do_display)
 {
 #ifdef USE_VTLOCK
 	/* EL - RCS : lock VT switching */
-	if (vtlock && !vtlocked)
+	if (!nolock && vtlock && !vtlocked)
 		dovtlock();
 #endif
 #if defined( HAVE_SYSLOG_H ) && defined( USE_SYSLOG )
@@ -2518,13 +2532,13 @@ lockDisplay(Display * display, Bool do_display)
 }
 
 static void
-read_plan()
+read_plan(void)
 {
 	FILE       *planf = NULL;
 	char        buf[121];
-	char       *home = getenv("HOME");
+	const char *home = getenv("HOME");
 	char       *buffer;
-	int         i, j, cr;
+	int         i, j, len;
 
 	if (!home)
 		home = "";
@@ -2587,13 +2601,12 @@ read_plan()
 	}
 	if (planf != NULL) {
 		for (i = 0; i < TEXTLINES; i++) {
-			if (fgets(buf, 120, planf)) {
-				cr = strlen(buf) - 1;
-				if (buf[cr] == '\n') {
-					buf[cr] = '\0';
+			if (fgets(buf, 120, planf) && (len = strlen(buf)) > 0) {
+				if (buf[len - 1] == '\n') {
+					buf[--len] = '\0';
 				}
 				/* this expands tabs to 8 spaces */
-				for (j = 0; j < cr; j++) {
+				for (j = 0; j < len; j++) {
 					if (buf[j] == '\t') {
 						int         k, tab = 8 - (j % 8);
 
@@ -2603,12 +2616,11 @@ read_plan()
 						for (k = j; k < j + tab; k++) {
 							buf[k] = ' ';
 						}
-						cr += tab;
-						if (cr > 120)
-							cr = 120;
+						len += tab;
+						if (len > 120)
+							len = 120;
 					}
 				}
-				buf[cr] = '\0';
 
 				plantext[i] = (char *) malloc(strlen(buf) + 1);
 				(void) strcpy(plantext[i], buf);
@@ -2970,6 +2982,31 @@ main(int argc, char **argv)
 		Screen     *scr = ScreenOfDisplay(dsp, screen);
 		Colormap    cmap = (Colormap) NULL;
 
+#ifdef USE_UNSTABLE
+/* Start of MI_ROOT_PIXMAP hack */
+		Window 			temp_rw;
+		XGCValues		temp_gcv;
+		GC			temp_gc;
+		XWindowAttributes	temp_xgwa;
+		
+		temp_rw = (parentSet) ? parent : RootWindowOfScreen(scr);
+		XGetWindowAttributes(dsp, temp_rw, &temp_xgwa);
+		temp_gcv.function = GXcopy;
+		temp_gcv.subwindow_mode = IncludeInferiors;
+		temp_gc = XCreateGC(dsp, temp_rw, GCFunction|GCSubwindowMode,
+				   &temp_gcv);
+		Scr[screen].root_pixmap = XCreatePixmap(dsp, temp_rw,
+						   temp_xgwa.width,
+						   temp_xgwa.height,
+						   temp_xgwa.depth);
+		XCopyArea(dsp, temp_rw, Scr[screen].root_pixmap,
+			  temp_gc, 0, 0, temp_xgwa.width, temp_xgwa.height,
+			  0, 0);
+		XFreeGC(dsp, temp_gc);
+						   
+/* End of MI_ROOT_PIXMAP hack */		
+#endif
+
 #ifdef ORIGINAL_XPM_PATCH
 		if (mailIcon && mailIcon[0]) {
 			if ((mail_xpmimg = (XpmImage *) malloc(sizeof (XpmImage))))
@@ -3260,11 +3297,6 @@ main(int argc, char **argv)
 		}
 #else
 		if (mailCmd && mailCmd[0]) {
-			extern void pickPixmap(Display * display, Drawable drawable, char *name,
-					       int default_width, int default_height, unsigned char *default_bits,
-				    int *width, int *height, Pixmap * pixmap,
-					       int *graphics_format);
-
 			pickPixmap(dsp, Scr[screen].window, nomailIcon,
 				   NOMAIL_WIDTH, NOMAIL_HEIGHT, NOMAIL_BITS,
 				   &(Scr[screen].mb.nomail.width),
